# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import mlp_api_pb2 as mlp__api__pb2


class CatalogStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateProject = channel.unary_unary(
        '/Catalog/CreateProject',
        request_serializer=mlp__api__pb2.CreateProjectRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.ProjectInfoResponse.FromString,
        )
    self.GetProject = channel.unary_unary(
        '/Catalog/GetProject',
        request_serializer=mlp__api__pb2.GetProjectRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.ProjectInfoResponse.FromString,
        )
    self.AddSystem = channel.unary_unary(
        '/Catalog/AddSystem',
        request_serializer=mlp__api__pb2.AddSystemRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.SystemInfoResponse.FromString,
        )
    self.GetSystem = channel.unary_unary(
        '/Catalog/GetSystem',
        request_serializer=mlp__api__pb2.GetSystemRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.SystemInfoResponse.FromString,
        )
    self.AddSystemVersion = channel.unary_unary(
        '/Catalog/AddSystemVersion',
        request_serializer=mlp__api__pb2.AddSystemVersionRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.AddSystemVersionResponse.FromString,
        )
    self.CreateJob = channel.unary_unary(
        '/Catalog/CreateJob',
        request_serializer=mlp__api__pb2.CreateJobRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.JobInfoResponse.FromString,
        )
    self.GetJob = channel.unary_unary(
        '/Catalog/GetJob',
        request_serializer=mlp__api__pb2.GetJobRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.JobInfoResponse.FromString,
        )
    self.StartJobRun = channel.unary_unary(
        '/Catalog/StartJobRun',
        request_serializer=mlp__api__pb2.StartJobRunRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.JobRunInfoResponse.FromString,
        )
    self.LogJobRun = channel.unary_unary(
        '/Catalog/LogJobRun',
        request_serializer=mlp__api__pb2.LogJobRunRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.EmptyResponse.FromString,
        )
    self.FailJobRun = channel.unary_unary(
        '/Catalog/FailJobRun',
        request_serializer=mlp__api__pb2.FailJobRunRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.EmptyResponse.FromString,
        )
    self.CompleteJobRun = channel.unary_unary(
        '/Catalog/CompleteJobRun',
        request_serializer=mlp__api__pb2.CompleteJobRunRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.EmptyResponse.FromString,
        )
    self.CreateDataset = channel.unary_unary(
        '/Catalog/CreateDataset',
        request_serializer=mlp__api__pb2.CreateDatasetRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.DatasetInfoResponse.FromString,
        )
    self.GetDataset = channel.unary_unary(
        '/Catalog/GetDataset',
        request_serializer=mlp__api__pb2.GetDatasetRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.DatasetInfoResponse.FromString,
        )
    self.UpdateDataset = channel.unary_unary(
        '/Catalog/UpdateDataset',
        request_serializer=mlp__api__pb2.UpdateDatasetRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.EmptyResponse.FromString,
        )
    self.GetLastDatasetVersion = channel.unary_unary(
        '/Catalog/GetLastDatasetVersion',
        request_serializer=mlp__api__pb2.GetLastDatasetVersionRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.DatasetVersionResponse.FromString,
        )
    self.Commit = channel.unary_unary(
        '/Catalog/Commit',
        request_serializer=mlp__api__pb2.CommitRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.CommitResponse.FromString,
        )
    self.Stat = channel.unary_unary(
        '/Catalog/Stat',
        request_serializer=mlp__api__pb2.StatRequest.SerializeToString,
        response_deserializer=mlp__api__pb2.StatResponse.FromString,
        )


class CatalogServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateProject(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetProject(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddSystem(self, request, context):
    """SYSTEMS ------------

    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSystem(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddSystemVersion(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateJob(self, request, context):
    """JOBS -----------------
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetJob(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartJobRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LogJobRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FailJobRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CompleteJobRun(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateDataset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDataset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateDataset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLastDatasetVersion(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Commit(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Stat(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CatalogServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateProject': grpc.unary_unary_rpc_method_handler(
          servicer.CreateProject,
          request_deserializer=mlp__api__pb2.CreateProjectRequest.FromString,
          response_serializer=mlp__api__pb2.ProjectInfoResponse.SerializeToString,
      ),
      'GetProject': grpc.unary_unary_rpc_method_handler(
          servicer.GetProject,
          request_deserializer=mlp__api__pb2.GetProjectRequest.FromString,
          response_serializer=mlp__api__pb2.ProjectInfoResponse.SerializeToString,
      ),
      'AddSystem': grpc.unary_unary_rpc_method_handler(
          servicer.AddSystem,
          request_deserializer=mlp__api__pb2.AddSystemRequest.FromString,
          response_serializer=mlp__api__pb2.SystemInfoResponse.SerializeToString,
      ),
      'GetSystem': grpc.unary_unary_rpc_method_handler(
          servicer.GetSystem,
          request_deserializer=mlp__api__pb2.GetSystemRequest.FromString,
          response_serializer=mlp__api__pb2.SystemInfoResponse.SerializeToString,
      ),
      'AddSystemVersion': grpc.unary_unary_rpc_method_handler(
          servicer.AddSystemVersion,
          request_deserializer=mlp__api__pb2.AddSystemVersionRequest.FromString,
          response_serializer=mlp__api__pb2.AddSystemVersionResponse.SerializeToString,
      ),
      'CreateJob': grpc.unary_unary_rpc_method_handler(
          servicer.CreateJob,
          request_deserializer=mlp__api__pb2.CreateJobRequest.FromString,
          response_serializer=mlp__api__pb2.JobInfoResponse.SerializeToString,
      ),
      'GetJob': grpc.unary_unary_rpc_method_handler(
          servicer.GetJob,
          request_deserializer=mlp__api__pb2.GetJobRequest.FromString,
          response_serializer=mlp__api__pb2.JobInfoResponse.SerializeToString,
      ),
      'StartJobRun': grpc.unary_unary_rpc_method_handler(
          servicer.StartJobRun,
          request_deserializer=mlp__api__pb2.StartJobRunRequest.FromString,
          response_serializer=mlp__api__pb2.JobRunInfoResponse.SerializeToString,
      ),
      'LogJobRun': grpc.unary_unary_rpc_method_handler(
          servicer.LogJobRun,
          request_deserializer=mlp__api__pb2.LogJobRunRequest.FromString,
          response_serializer=mlp__api__pb2.EmptyResponse.SerializeToString,
      ),
      'FailJobRun': grpc.unary_unary_rpc_method_handler(
          servicer.FailJobRun,
          request_deserializer=mlp__api__pb2.FailJobRunRequest.FromString,
          response_serializer=mlp__api__pb2.EmptyResponse.SerializeToString,
      ),
      'CompleteJobRun': grpc.unary_unary_rpc_method_handler(
          servicer.CompleteJobRun,
          request_deserializer=mlp__api__pb2.CompleteJobRunRequest.FromString,
          response_serializer=mlp__api__pb2.EmptyResponse.SerializeToString,
      ),
      'CreateDataset': grpc.unary_unary_rpc_method_handler(
          servicer.CreateDataset,
          request_deserializer=mlp__api__pb2.CreateDatasetRequest.FromString,
          response_serializer=mlp__api__pb2.DatasetInfoResponse.SerializeToString,
      ),
      'GetDataset': grpc.unary_unary_rpc_method_handler(
          servicer.GetDataset,
          request_deserializer=mlp__api__pb2.GetDatasetRequest.FromString,
          response_serializer=mlp__api__pb2.DatasetInfoResponse.SerializeToString,
      ),
      'UpdateDataset': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateDataset,
          request_deserializer=mlp__api__pb2.UpdateDatasetRequest.FromString,
          response_serializer=mlp__api__pb2.EmptyResponse.SerializeToString,
      ),
      'GetLastDatasetVersion': grpc.unary_unary_rpc_method_handler(
          servicer.GetLastDatasetVersion,
          request_deserializer=mlp__api__pb2.GetLastDatasetVersionRequest.FromString,
          response_serializer=mlp__api__pb2.DatasetVersionResponse.SerializeToString,
      ),
      'Commit': grpc.unary_unary_rpc_method_handler(
          servicer.Commit,
          request_deserializer=mlp__api__pb2.CommitRequest.FromString,
          response_serializer=mlp__api__pb2.CommitResponse.SerializeToString,
      ),
      'Stat': grpc.unary_unary_rpc_method_handler(
          servicer.Stat,
          request_deserializer=mlp__api__pb2.StatRequest.FromString,
          response_serializer=mlp__api__pb2.StatResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'Catalog', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from dataclasses import dataclass
from typing import Callable, Optional

from . import mlp_api_pb2 as api
from . import mlp_api_pb2_grpc as rpc
import grpc
from . import errors
import os
import google.protobuf.message as pb



class EntityId:
    def __init__(self, uid: bytes):
        self.uid= uid

class JobRunId (EntityId):
    pass


class DatasetVersionId(EntityId):
    pass

class SystemId(EntityId):
    pass



class Context:

    def __init__(self, catalog: rpc.CatalogStub):
        self.catalog = catalog

    def get_project(self, req: api.GetProjectRequest) -> api.ProjectInfoResponse:
        resp: api.ProjectInfoResponse = self._rpc(lambda: self.catalog.GetProject(req))
        return resp

    def create_project(self, req: api.CreateProjectRequest) -> api.ProjectInfoResponse:
        resp: api.ProjectInfoResponse = self._rpc(lambda: self.catalog.CreateProject(req))
        return resp

    def get_job(self, req: api.GetJobRequest) -> api.JobInfoResponse:
        s: api.JobInfoResponse = self._rpc(lambda: self.catalog.GetJob(req))
        return s

    def create_job(self, req: api.CreateJobRequest) -> api.JobInfoResponse:
        s: api.JobInfoResponse = self._rpc(lambda: self.catalog.CreateJob(req))
        return s

    def create_dataset(self, req: api.CreateDatasetRequest) -> api.DatasetInfoResponse:
        s: api.DatasetInfoResponse = self._rpc(lambda: self.catalog.CreateDataset(req))
        return s

    def get_dataset(self, req: api.GetDatasetRequest) -> api.DatasetInfoResponse:
        s: api.DatasetInfoResponse = self._rpc(lambda: self.catalog.GetDataset(req))
        return s

    def get_last_version(self, req: api.GetLastDatasetVersionRequest) -> api.DatasetVersionResponse:
        s: api.DatasetVersionResponse = self._rpc(lambda: self.catalog.GetLastDatasetVersion(req))
        return s

    def start_job_run(self, req: api.StartJobRunRequest) -> api.JobRunInfoResponse:
        s: api.JobRunInfoResponse = self._rpc(lambda: self.catalog.StartJobRun(req))
        return s

    def log_job_run(self, req: api.LogJobRunRequest) -> api.EmptyResponse:
        s: api.EmptyResponse = self._rpc(lambda: self.catalog.LogJobRun(req))
        return s

    def complete_job_run(self, req: api.CompleteJobRunRequest) -> api.EmptyResponse:
        s: api.EmptyResponse = self._rpc(lambda: self.catalog.CompleteJobRun(req))
        return s

    def fail_job_run(self, req: api.FailJobRunRequest) -> api.EmptyResponse:
        s: api.EmptyResponse = self._rpc(lambda: self.catalog.FailJobRun(req))
        return s

    def commit(self, req: api.CommitRequest) -> api.CommitResponse:
        s: api.CommitResponse = self._rpc(lambda: self.catalog.Commit(req))
        return s

    def stat(self, req: api.StatRequest) -> api.StatResponse:
        s: api.StatResponse = self._rpc(lambda: self.catalog.Stat(req))
        return s

    def add_system(self, req: api.AddSystemRequest) -> api.SystemInfoResponse:
        s: api.SystemInfoResponse = self._rpc(lambda : self.catalog.AddSystem(req))
        return s

    def add_system_version(self, r: api.AddSystemVersionRequest) -> api.AddSystemVersionResponse:
        s: api.AddSystemVersionResponse = self._rpc(lambda : self.catalog.AddSystemVersion(r))
        return s
    def get_system(self, r: api.GetSystemRequest)-> api.SystemInfoResponse:
        s: api.SystemInfoResponse = self._rpc(lambda : self.catalog.GetSystem(r))
        return s

    def _rpc(self, callable: Callable[[], pb.Message]):
        try:

            resp = callable()

            if not hasattr(resp,"error"):

                raise ValueError(print(f'{resp.__class__} has no error attribute'))

            if resp.error.code != 0:
                raise errors.from_error(resp.error)

            return resp
        except grpc.RpcError as e:
            raise errors.from_exception(e)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='vo.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x08vo.proto\"f\n\x14ProjectMetadataDelta\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\ttitle_set\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65scription_set\x18\x04 \x01(\x08\"\x96\x02\n\x13SystemMetadataDelta\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\ttitle_set\x18\x02 \x01(\x08\x12\x13\n\x0blocation_id\x18\x03 \x01(\t\x12\x17\n\x0flocation_id_set\x18\x04 \x01(\x08\x12\x14\n\x0clocation_uri\x18\x05 \x01(\t\x12\x18\n\x10location_uri_set\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x17\n\x0f\x64\x65scription_set\x18\x08 \x01(\x08\x12\x0f\n\x07\x65xperts\x18\t \x03(\x0c\x12\x13\n\x0b\x65xperts_set\x18\n \x01(\x08\x12\x19\n\x04kind\x18\x0b \x01(\x0e\x32\x0b.SystemKind\x12\x10\n\x08kind_set\x18\x0c \x01(\x08\"a\n\x13\x45xpertMetadataDelta\x12\x11\n\tfull_name\x18\x01 \x01(\t\x12\x15\n\rfull_name_set\x18\x02 \x01(\x08\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x11\n\temail_set\x18\x04 \x01(\x08\";\n\x08Relation\x12\x11\n\ttarget_id\x18\x01 \x01(\x0c\x12\x1c\n\x0btarget_type\x18\x02 \x01(\x0e\x32\x07.ENTITY\"4\n\x10JobMetadataDelta\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\ttitle_set\x18\x02 \x01(\x08\"s\n\x12SystemVersionInput\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.SystemVersionInput.Type\"(\n\x04Type\x12\x08\n\x04None\x10\x00\x12\n\n\x06System\x10\x01\x12\n\n\x06JobRun\x10\x02\"i\n\x13SystemVersionOutput\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\'\n\x04type\x18\x02 \x01(\x0e\x32\x19.SystemVersionOutput.Type\"\x1c\n\x04Type\x12\x08\n\x04None\x10\x00\x12\n\n\x06System\x10\x01\"i\n\x0bJobRunInput\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x1f\n\x04type\x18\x02 \x01(\x0e\x32\x11.JobRunInput.Type\",\n\x04Type\x12\x08\n\x04None\x10\x00\x12\x0e\n\nDatasetVer\x10\x01\x12\n\n\x06System\x10\x02\"\\\n\tJobOutput\x12\x11\n\ttarget_id\x18\x01 \x01(\x0c\x12\x1d\n\x04type\x18\x02 \x01(\x0e\x32\x0f.JobOutput.Type\"\x1d\n\x04Type\x12\x08\n\x04None\x10\x00\x12\x0b\n\x07\x44\x61taset\x10\x01\"b\n\x0f\x44\x61tasetVerInput\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12#\n\x04type\x18\x02 \x01(\x0e\x32\x15.DatasetVerInput.TYPE\"\x1d\n\x04TYPE\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07JOB_RUN\x10\x01\"d\n\x10\x44\x61tasetVerOutput\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12$\n\x04type\x18\x02 \x01(\x0e\x32\x16.DatasetVerOutput.TYPE\"\x1d\n\x04TYPE\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07JOB_RUN\x10\x01\"\xcc\x02\n\x14\x44\x61tasetMetadataDelta\x12\x1e\n\x06sample\x18\x07 \x01(\x0b\x32\x0e.DatasetSample\x12\x12\n\nsample_set\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x61ta_format\x18\x0b \x01(\t\x12\x17\n\x0f\x64\x61ta_format_set\x18\x0c \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\x12\x17\n\x0f\x64\x65scription_set\x18\x0e \x01(\x08\x12\x13\n\x0blocation_id\x18\x0f \x01(\t\x12\x17\n\x0flocation_id_set\x18\x10 \x01(\x08\x12\x14\n\x0clocation_uri\x18\x11 \x01(\t\x12\x18\n\x10location_uri_set\x18\x12 \x01(\x08\x12\x0f\n\x07\x65xperts\x18\x13 \x03(\x0c\x12\x13\n\x0b\x65xperts_set\x18\x14 \x01(\x08\x12\r\n\x05title\x18\x15 \x01(\t\x12\x11\n\ttitle_set\x18\x16 \x01(\x08\"P\n\x0b\x44\x61tasetItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rstorage_bytes\x18\x02 \x01(\x03\x12\x0f\n\x07records\x18\x03 \x01(\x03\x12\x0b\n\x03uid\x18\x04 \x01(\x0c\"k\n\rDatasetSample\x12%\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x15.DatasetSample.FORMAT\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\"%\n\x06\x46ORMAT\x12\x08\n\x04TEXT\x10\x00\x12\x07\n\x03TSV\x10\x01\x12\x08\n\x04JSON\x10\x02*^\n\nSystemKind\x12\x13\n\x0fUndefinedSystem\x10\x00\x12\t\n\x05Table\x10\x01\x12\t\n\x05Topic\x10\x02\x12\x0b\n\x07Service\x10\x03\x12\n\n\x06Report\x10\x04\x12\x0c\n\x08\x44\x61tabase\x10\x05*\x82\x01\n\x06\x45NTITY\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x44\x41TASET\x10\x01\x12\x07\n\x03JOB\x10\x02\x12\n\n\x06SYSTEM\x10\x03\x12\t\n\x05MODEL\x10\x04\x12\x0b\n\x07PROJECT\x10\x05\x12\x13\n\x0f\x44\x41TASET_VERSION\x10\x06\x12\x0b\n\x07JOB_RUN\x10\x07\x12\x12\n\x0eSYSTEM_VERSION\x10\t*;\n\nJOB_STATUS\x12\t\n\x05NEVER\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x08\n\x04\x46\x41IL\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x62\x06proto3')
)

_SYSTEMKIND = _descriptor.EnumDescriptor(
  name='SystemKind',
  full_name='SystemKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UndefinedSystem', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Table', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Topic', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Service', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Report', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Database', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1764,
  serialized_end=1858,
)
_sym_db.RegisterEnumDescriptor(_SYSTEMKIND)

SystemKind = enum_type_wrapper.EnumTypeWrapper(_SYSTEMKIND)
_ENTITY = _descriptor.EnumDescriptor(
  name='ENTITY',
  full_name='ENTITY',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATASET', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROJECT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATASET_VERSION', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_RUN', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM_VERSION', index=8, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1861,
  serialized_end=1991,
)
_sym_db.RegisterEnumDescriptor(_ENTITY)

ENTITY = enum_type_wrapper.EnumTypeWrapper(_ENTITY)
_JOB_STATUS = _descriptor.EnumDescriptor(
  name='JOB_STATUS',
  full_name='JOB_STATUS',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEVER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1993,
  serialized_end=2052,
)
_sym_db.RegisterEnumDescriptor(_JOB_STATUS)

JOB_STATUS = enum_type_wrapper.EnumTypeWrapper(_JOB_STATUS)
UndefinedSystem = 0
Table = 1
Topic = 2
Service = 3
Report = 4
Database = 5
NONE = 0
DATASET = 1
JOB = 2
SYSTEM = 3
MODEL = 4
PROJECT = 5
DATASET_VERSION = 6
JOB_RUN = 7
SYSTEM_VERSION = 9
NEVER = 0
SUCCESS = 1
FAIL = 2
RUNNING = 3


_SYSTEMVERSIONINPUT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='SystemVersionInput.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='System', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JobRun', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=686,
  serialized_end=726,
)
_sym_db.RegisterEnumDescriptor(_SYSTEMVERSIONINPUT_TYPE)

_SYSTEMVERSIONOUTPUT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='SystemVersionOutput.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='System', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=686,
  serialized_end=714,
)
_sym_db.RegisterEnumDescriptor(_SYSTEMVERSIONOUTPUT_TYPE)

_JOBRUNINPUT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='JobRunInput.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DatasetVer', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='System', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=896,
  serialized_end=940,
)
_sym_db.RegisterEnumDescriptor(_JOBRUNINPUT_TYPE)

_JOBOUTPUT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='JobOutput.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Dataset', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1005,
  serialized_end=1034,
)
_sym_db.RegisterEnumDescriptor(_JOBOUTPUT_TYPE)

_DATASETVERINPUT_TYPE = _descriptor.EnumDescriptor(
  name='TYPE',
  full_name='DatasetVerInput.TYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_RUN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1105,
  serialized_end=1134,
)
_sym_db.RegisterEnumDescriptor(_DATASETVERINPUT_TYPE)

_DATASETVEROUTPUT_TYPE = _descriptor.EnumDescriptor(
  name='TYPE',
  full_name='DatasetVerOutput.TYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOB_RUN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1105,
  serialized_end=1134,
)
_sym_db.RegisterEnumDescriptor(_DATASETVEROUTPUT_TYPE)

_DATASETSAMPLE_FORMAT = _descriptor.EnumDescriptor(
  name='FORMAT',
  full_name='DatasetSample.FORMAT',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSV', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1725,
  serialized_end=1762,
)
_sym_db.RegisterEnumDescriptor(_DATASETSAMPLE_FORMAT)


_PROJECTMETADATADELTA = _descriptor.Descriptor(
  name='ProjectMetadataDelta',
  full_name='ProjectMetadataDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='ProjectMetadataDelta.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title_set', full_name='ProjectMetadataDelta.title_set', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='ProjectMetadataDelta.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_set', full_name='ProjectMetadataDelta.description_set', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12,
  serialized_end=114,
)


_SYSTEMMETADATADELTA = _descriptor.Descriptor(
  name='SystemMetadataDelta',
  full_name='SystemMetadataDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='SystemMetadataDelta.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title_set', full_name='SystemMetadataDelta.title_set', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='SystemMetadataDelta.location_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_id_set', full_name='SystemMetadataDelta.location_id_set', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_uri', full_name='SystemMetadataDelta.location_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_uri_set', full_name='SystemMetadataDelta.location_uri_set', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='SystemMetadataDelta.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_set', full_name='SystemMetadataDelta.description_set', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experts', full_name='SystemMetadataDelta.experts', index=8,
      number=9, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experts_set', full_name='SystemMetadataDelta.experts_set', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='SystemMetadataDelta.kind', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind_set', full_name='SystemMetadataDelta.kind_set', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=395,
)


_EXPERTMETADATADELTA = _descriptor.Descriptor(
  name='ExpertMetadataDelta',
  full_name='ExpertMetadataDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='full_name', full_name='ExpertMetadataDelta.full_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_name_set', full_name='ExpertMetadataDelta.full_name_set', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='ExpertMetadataDelta.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email_set', full_name='ExpertMetadataDelta.email_set', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=494,
)


_RELATION = _descriptor.Descriptor(
  name='Relation',
  full_name='Relation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_id', full_name='Relation.target_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_type', full_name='Relation.target_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=496,
  serialized_end=555,
)


_JOBMETADATADELTA = _descriptor.Descriptor(
  name='JobMetadataDelta',
  full_name='JobMetadataDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='JobMetadataDelta.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title_set', full_name='JobMetadataDelta.title_set', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=557,
  serialized_end=609,
)


_SYSTEMVERSIONINPUT = _descriptor.Descriptor(
  name='SystemVersionInput',
  full_name='SystemVersionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='SystemVersionInput.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='SystemVersionInput.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYSTEMVERSIONINPUT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=726,
)


_SYSTEMVERSIONOUTPUT = _descriptor.Descriptor(
  name='SystemVersionOutput',
  full_name='SystemVersionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='SystemVersionOutput.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='SystemVersionOutput.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYSTEMVERSIONOUTPUT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=728,
  serialized_end=833,
)


_JOBRUNINPUT = _descriptor.Descriptor(
  name='JobRunInput',
  full_name='JobRunInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='JobRunInput.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='JobRunInput.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JOBRUNINPUT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=940,
)


_JOBOUTPUT = _descriptor.Descriptor(
  name='JobOutput',
  full_name='JobOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_id', full_name='JobOutput.target_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='JobOutput.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JOBOUTPUT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=942,
  serialized_end=1034,
)


_DATASETVERINPUT = _descriptor.Descriptor(
  name='DatasetVerInput',
  full_name='DatasetVerInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='DatasetVerInput.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='DatasetVerInput.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATASETVERINPUT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1134,
)


_DATASETVEROUTPUT = _descriptor.Descriptor(
  name='DatasetVerOutput',
  full_name='DatasetVerOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='DatasetVerOutput.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='DatasetVerOutput.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATASETVEROUTPUT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1236,
)


_DATASETMETADATADELTA = _descriptor.Descriptor(
  name='DatasetMetadataDelta',
  full_name='DatasetMetadataDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample', full_name='DatasetMetadataDelta.sample', index=0,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_set', full_name='DatasetMetadataDelta.sample_set', index=1,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_format', full_name='DatasetMetadataDelta.data_format', index=2,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_format_set', full_name='DatasetMetadataDelta.data_format_set', index=3,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='DatasetMetadataDelta.description', index=4,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_set', full_name='DatasetMetadataDelta.description_set', index=5,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='DatasetMetadataDelta.location_id', index=6,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_id_set', full_name='DatasetMetadataDelta.location_id_set', index=7,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_uri', full_name='DatasetMetadataDelta.location_uri', index=8,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_uri_set', full_name='DatasetMetadataDelta.location_uri_set', index=9,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experts', full_name='DatasetMetadataDelta.experts', index=10,
      number=19, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experts_set', full_name='DatasetMetadataDelta.experts_set', index=11,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='DatasetMetadataDelta.title', index=12,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title_set', full_name='DatasetMetadataDelta.title_set', index=13,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1571,
)


_DATASETITEM = _descriptor.Descriptor(
  name='DatasetItem',
  full_name='DatasetItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='DatasetItem.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_bytes', full_name='DatasetItem.storage_bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='records', full_name='DatasetItem.records', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='DatasetItem.uid', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1573,
  serialized_end=1653,
)


_DATASETSAMPLE = _descriptor.Descriptor(
  name='DatasetSample',
  full_name='DatasetSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='DatasetSample.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='DatasetSample.body', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATASETSAMPLE_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1762,
)

_SYSTEMMETADATADELTA.fields_by_name['kind'].enum_type = _SYSTEMKIND
_RELATION.fields_by_name['target_type'].enum_type = _ENTITY
_SYSTEMVERSIONINPUT.fields_by_name['type'].enum_type = _SYSTEMVERSIONINPUT_TYPE
_SYSTEMVERSIONINPUT_TYPE.containing_type = _SYSTEMVERSIONINPUT
_SYSTEMVERSIONOUTPUT.fields_by_name['type'].enum_type = _SYSTEMVERSIONOUTPUT_TYPE
_SYSTEMVERSIONOUTPUT_TYPE.containing_type = _SYSTEMVERSIONOUTPUT
_JOBRUNINPUT.fields_by_name['type'].enum_type = _JOBRUNINPUT_TYPE
_JOBRUNINPUT_TYPE.containing_type = _JOBRUNINPUT
_JOBOUTPUT.fields_by_name['type'].enum_type = _JOBOUTPUT_TYPE
_JOBOUTPUT_TYPE.containing_type = _JOBOUTPUT
_DATASETVERINPUT.fields_by_name['type'].enum_type = _DATASETVERINPUT_TYPE
_DATASETVERINPUT_TYPE.containing_type = _DATASETVERINPUT
_DATASETVEROUTPUT.fields_by_name['type'].enum_type = _DATASETVEROUTPUT_TYPE
_DATASETVEROUTPUT_TYPE.containing_type = _DATASETVEROUTPUT
_DATASETMETADATADELTA.fields_by_name['sample'].message_type = _DATASETSAMPLE
_DATASETSAMPLE.fields_by_name['format'].enum_type = _DATASETSAMPLE_FORMAT
_DATASETSAMPLE_FORMAT.containing_type = _DATASETSAMPLE
DESCRIPTOR.message_types_by_name['ProjectMetadataDelta'] = _PROJECTMETADATADELTA
DESCRIPTOR.message_types_by_name['SystemMetadataDelta'] = _SYSTEMMETADATADELTA
DESCRIPTOR.message_types_by_name['ExpertMetadataDelta'] = _EXPERTMETADATADELTA
DESCRIPTOR.message_types_by_name['Relation'] = _RELATION
DESCRIPTOR.message_types_by_name['JobMetadataDelta'] = _JOBMETADATADELTA
DESCRIPTOR.message_types_by_name['SystemVersionInput'] = _SYSTEMVERSIONINPUT
DESCRIPTOR.message_types_by_name['SystemVersionOutput'] = _SYSTEMVERSIONOUTPUT
DESCRIPTOR.message_types_by_name['JobRunInput'] = _JOBRUNINPUT
DESCRIPTOR.message_types_by_name['JobOutput'] = _JOBOUTPUT
DESCRIPTOR.message_types_by_name['DatasetVerInput'] = _DATASETVERINPUT
DESCRIPTOR.message_types_by_name['DatasetVerOutput'] = _DATASETVEROUTPUT
DESCRIPTOR.message_types_by_name['DatasetMetadataDelta'] = _DATASETMETADATADELTA
DESCRIPTOR.message_types_by_name['DatasetItem'] = _DATASETITEM
DESCRIPTOR.message_types_by_name['DatasetSample'] = _DATASETSAMPLE
DESCRIPTOR.enum_types_by_name['SystemKind'] = _SYSTEMKIND
DESCRIPTOR.enum_types_by_name['ENTITY'] = _ENTITY
DESCRIPTOR.enum_types_by_name['JOB_STATUS'] = _JOB_STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProjectMetadataDelta = _reflection.GeneratedProtocolMessageType('ProjectMetadataDelta', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTMETADATADELTA,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:ProjectMetadataDelta)
  })
_sym_db.RegisterMessage(ProjectMetadataDelta)

SystemMetadataDelta = _reflection.GeneratedProtocolMessageType('SystemMetadataDelta', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMMETADATADELTA,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:SystemMetadataDelta)
  })
_sym_db.RegisterMessage(SystemMetadataDelta)

ExpertMetadataDelta = _reflection.GeneratedProtocolMessageType('ExpertMetadataDelta', (_message.Message,), {
  'DESCRIPTOR' : _EXPERTMETADATADELTA,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:ExpertMetadataDelta)
  })
_sym_db.RegisterMessage(ExpertMetadataDelta)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:Relation)
  })
_sym_db.RegisterMessage(Relation)

JobMetadataDelta = _reflection.GeneratedProtocolMessageType('JobMetadataDelta', (_message.Message,), {
  'DESCRIPTOR' : _JOBMETADATADELTA,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:JobMetadataDelta)
  })
_sym_db.RegisterMessage(JobMetadataDelta)

SystemVersionInput = _reflection.GeneratedProtocolMessageType('SystemVersionInput', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMVERSIONINPUT,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:SystemVersionInput)
  })
_sym_db.RegisterMessage(SystemVersionInput)

SystemVersionOutput = _reflection.GeneratedProtocolMessageType('SystemVersionOutput', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMVERSIONOUTPUT,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:SystemVersionOutput)
  })
_sym_db.RegisterMessage(SystemVersionOutput)

JobRunInput = _reflection.GeneratedProtocolMessageType('JobRunInput', (_message.Message,), {
  'DESCRIPTOR' : _JOBRUNINPUT,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:JobRunInput)
  })
_sym_db.RegisterMessage(JobRunInput)

JobOutput = _reflection.GeneratedProtocolMessageType('JobOutput', (_message.Message,), {
  'DESCRIPTOR' : _JOBOUTPUT,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:JobOutput)
  })
_sym_db.RegisterMessage(JobOutput)

DatasetVerInput = _reflection.GeneratedProtocolMessageType('DatasetVerInput', (_message.Message,), {
  'DESCRIPTOR' : _DATASETVERINPUT,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:DatasetVerInput)
  })
_sym_db.RegisterMessage(DatasetVerInput)

DatasetVerOutput = _reflection.GeneratedProtocolMessageType('DatasetVerOutput', (_message.Message,), {
  'DESCRIPTOR' : _DATASETVEROUTPUT,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:DatasetVerOutput)
  })
_sym_db.RegisterMessage(DatasetVerOutput)

DatasetMetadataDelta = _reflection.GeneratedProtocolMessageType('DatasetMetadataDelta', (_message.Message,), {
  'DESCRIPTOR' : _DATASETMETADATADELTA,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:DatasetMetadataDelta)
  })
_sym_db.RegisterMessage(DatasetMetadataDelta)

DatasetItem = _reflection.GeneratedProtocolMessageType('DatasetItem', (_message.Message,), {
  'DESCRIPTOR' : _DATASETITEM,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:DatasetItem)
  })
_sym_db.RegisterMessage(DatasetItem)

DatasetSample = _reflection.GeneratedProtocolMessageType('DatasetSample', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSAMPLE,
  '__module__' : 'vo_pb2'
  # @@protoc_insertion_point(class_scope:DatasetSample)
  })
_sym_db.RegisterMessage(DatasetSample)


# @@protoc_insertion_point(module_scope)



from typing import Optional, List, Any

from .cl_bases import *
from . import vo_pb2 as vo



class DatasetStaging:
    files: List[vo.DatasetItem]

    def __init__(self, ctx: Context, project_uid: bytes, dataset_uid: bytes, version_uid: bytes, clean_slate: bool, dataset_name: str):
        self.dataset_name = dataset_name
        self.version_uid = version_uid
        self.dataset_uid = dataset_uid
        self.project_uid = project_uid
        self.clean_slate = clean_slate
        self.ctx = ctx

        self.files = []
        self.inputs = []

    def add_file(self, name: str, size: int, records: int=0):
        self.files.append(vo.DatasetItem(name=name, storage_bytes=size, records=records))

    def add_input(self, run: JobRunId):

        if isinstance(run, JobRunId):
            i = vo.DatasetVerInput(uid=run.uid, type=vo.DatasetVerInput.TYPE.JOB_RUN)
            self.inputs.append(i)
            return
        raise ValueError(f'Unexpected dependency: {run.__class__}')

    def commit(self, title: Optional[str]=None) -> 'DatasetVersion':

        change_set = api.DatasetChangeSet(
            dataset_uid=self.dataset_uid,
            parent_version_uid=self.version_uid,
            clean_slate=self.clean_slate,
        )

        change_set.inputs.extend(self.inputs)
        change_set.items.extend(self.files)

        r = api.CommitRequest(
            title=title,
        )

        r.datasets.append(change_set)




        resp = self.ctx.commit(r)
        return DatasetVersion(
            self.ctx,
            project_uid=self.project_uid,
            dataset_uid=self.dataset_uid,
            dataset_name=self.dataset_name,
            uid = resp.dataset_versions[0]
        )


class DatasetVersion(DatasetVersionId):
    def __init__(self, ctx: Context, project_uid, dataset_uid, dataset_name, uid):
        super().__init__(uid)
        self.dataset_name = dataset_name
        self.dataset_uid = dataset_uid
        self.project_uid = project_uid

        self.ctx = ctx

    def headless(self) -> bool:
        return self.uid is None

    def prepare_commit(self, clean_slate: bool = False) -> DatasetStaging:
        return DatasetStaging(
            self.ctx,
            self.project_uid,
            self.dataset_uid,
            self.uid,
            clean_slate,
            self.dataset_name
        )


class Dataset:
    def __init__(self, ctx: Context, project_uid, uid, name, location_id: str):
        self.location_id = location_id
        self.name = name
        self.uid = uid
        self.project_uid = project_uid
        self.ctx = ctx

    def get_last_version(self) -> DatasetVersion:
        try:
            req = api.GetLastDatasetVersionRequest(project_uid=self.project_uid, dataset_uid=self.uid)
            resp = self.ctx.get_last_version(req)

            return DatasetVersion(self.ctx, self.project_uid, self.uid, self.name, resp.uid)
        except errors.NotFound:

            return DatasetVersion(self.ctx, self.project_uid, self.uid, self.name, None)
